"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFolderAndFiles = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const createFolderAndFiles = ({ dir, appName }) => {
    if (!fs_1.default.existsSync(appName)) {
        fs_1.default.mkdirSync(appName);
        console.log("Successfully created App Name :", appName);
    }
    const currentPath = path_1.default.join(appName);
    createDir({ structure: dir, basePath: currentPath });
    return;
};
exports.createFolderAndFiles = createFolderAndFiles;
const createDir = ({ structure, basePath }) => {
    if (Array.isArray(structure)) {
        structure.forEach((item) => {
            let folderPath = item.folder
                ? item.folder !== "root"
                    ? path_1.default.join(basePath, item.folder)
                    : basePath
                : basePath;
            if (!fs_1.default.existsSync(folderPath)) {
                fs_1.default.mkdirSync(folderPath);
                // console.log(`Folder '${folderPath}' created.`);
            }
            if (item.files) {
                item.files.forEach((file) => {
                    if (file.folder) {
                        createDir({ structure: item.files, basePath: folderPath });
                    }
                    else {
                        Object.entries(file).forEach((fileObj) => {
                            createFiles(fileObj, folderPath);
                        });
                    }
                });
            }
            if (item instanceof Object && !Array.isArray(item.files)) {
                createFiles(item, folderPath);
            }
        });
    }
    else {
        Object.entries(structure).forEach(([key, value]) => {
            let fullPath;
            if (value.folder === "root") {
                fullPath = path_1.default.join(basePath);
            }
            else {
                fullPath = path_1.default.join(basePath, value.folder || key);
            }
            if (!fs_1.default.existsSync(fullPath)) {
                fs_1.default.mkdirSync(fullPath);
                // console.log(`Folder '${fullPath}' created.`);
            }
            if (value.files) {
                createDir({ structure: value.files, basePath: fullPath });
            }
        });
    }
};
function createFiles(fileObj, folderPath) {
    for (const value of Object.values(fileObj)) {
        const obj = value;
        if (obj.folder) {
            const childFolderPath = path_1.default.join(folderPath, obj.folder);
            createDir({ structure: obj.files, basePath: childFolderPath });
        }
        else {
            if (typeof obj.fileName === "string" &&
                (obj.fileName.endsWith(".js") ||
                    obj.fileName === "www" ||
                    obj.fileName.endsWith(".html") ||
                    obj.fileName.endsWith(".json") ||
                    obj.fileName.endsWith(".gitignore"))) {
                // console.log('Value =>', value);
                const filePath = path_1.default.join(folderPath, obj.fileName);
                if (!fs_1.default.existsSync(filePath)) {
                    fs_1.default.writeFileSync(filePath, obj.content);
                    // console.log(`File '${filePath}' created.`);
                }
            }
        }
    }
    return;
}
