const express = require("express");
  const cors = require("cors");
  const compression = require("compression");
  const morgan = require("morgan");
  const path = require("path");
  const helmet = require("helmet");
  
  // imports
  const { logger } = require("./src/utils");
  const indexRoutes = require("./src/routes");
  const { errorHandler, routeHandler } = require("./src/helpers");
  
  // dbConnection
  require("./src/database");
  
  // express servers
  const app = express();
  
  // mongoose connection
  
  app.use(express.json());
  app.use(express.urlencoded({ extended: true, parameterLimit: 1000000 }));
  app.use(compression());
  app.use(compression());
  
  app.use(
    cors({
      origin: "*",
      methods: "GET,HEAD,PUT,PATCH,POST,DELETE",
      credentials: true,
      optionsSuccessStatus: 204,
    })
  );
  
  app.use(helmet());
  app.use(
    morgan(
      "[:date[web]] :method :url :status :response-time ms - :res[content-length]"
    )
  );
  
  // Enabled CORS
  app.use((req, res, next) => {
    res.setHeader("Access-Control-Allow-Origin", "*");
    res.header("Access-Control-Allow-Methods", "GET,PUT,POST,PATCH,DELETE");
    res.header("Access-Control-Allow-Headers", "Content-Type, Authorization");
  
    // intercept OPTIONS method
    if (req.method === "OPTIONS") {
      res.send(200);
    } else {
      next();
    }
  });
  
  // Public Path
  const publicPath = path.join(__dirname, "src/public");
  app.use(express.static(publicPath));
  
  // api Routes
  app.use("/api/v1", indexRoutes);
  
  // errorHandler
  app.use(errorHandler);
  
  // routesHandler
  app.use(routeHandler);
  
  // handle exceptions
  process.on("uncaughtException", function () {
    logger.error(err);
  });
  
  // handle rejection
  process.on("unhandledRejection", function (err) {
    logger.error(err);
  });
  
  module.exports = app;
  